chainalysis.sql.sql - Data Solutions Python SDK 0.7.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# Source code for chainalysis.sql.sql

    from chainalysis.sql.analytical import Analytical
    from chainalysis.sql.transactional import Transactional

    class Sql:

        def __init__(self, api_key: str):
            self.transactional = Transactional(api_key)
            self.analytical = Analytical(api_key)